@@ -16,9 +16,9 @@ use nix::{
 
 use crate::{
     fs::FsFlags,
-    hook::{PathArgs, SysArg, UNotifyEventRequest},
     kernel::{syscall_path_handler, to_mode},
     proc::proc_umask,
+    req::{PathArgs, SysArg, UNotifyEventRequest},
 };
 
 pub(crate) fn sys_mkdir(request: UNotifyEventRequest) -> ScmpNotifResp {
